==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/drafts/com/sun/star/form/XListEntryListener.hpp <==
#ifndef _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_
#define _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HDL_
#include "drafts/com/sun/star/form/XListEntryListener.hdl"
#endif

#ifndef _COM_SUN_STAR_LANG_XEVENTLISTENER_HPP_
#include "com/sun/star/lang/XEventListener.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_
#include "drafts/com/sun/star/form/ListEntryEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::drafts::com::sun::star::form::XListEntryListener >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "drafts.com.sun.star.form.XListEntryListener" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::drafts::com::sun::star::form::XListEntryListener::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::drafts::com::sun::star::form::XListEntryListener > * >(0));
}

#endif // _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/drafts/com/sun/star/form/XListEntryListener.hpp <==
#ifndef _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_
#define _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HDL_
#include "drafts/com/sun/star/form/XListEntryListener.hdl"
#endif

#ifndef _COM_SUN_STAR_LANG_XEVENTLISTENER_HPP_
#include "com/sun/star/lang/XEventListener.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _DRAFTS_COM_SUN_STAR_FORM_LISTENTRYEVENT_HPP_
#include "drafts/com/sun/star/form/ListEntryEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_EVENTOBJECT_HPP_
#include "com/sun/star/lang/EventObject.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace drafts { namespace com { namespace sun { namespace star { namespace form {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::drafts::com::sun::star::form::XListEntryListener const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "drafts.com.sun.star.form.XListEntryListener" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::drafts::com::sun::star::form::XListEntryListener > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::drafts::com::sun::star::form::XListEntryListener > >::get();
}

::com::sun::star::uno::Type const & ::drafts::com::sun::star::form::XListEntryListener::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::drafts::com::sun::star::form::XListEntryListener > * >(0));
}

#endif // _DRAFTS_COM_SUN_STAR_FORM_XLISTENTRYLISTENER_HPP_
